@@ -17,4 +17,8 @@ ERROR_PROJECT_NOT_FOUND = 10
 ERROR_BAD_PROFILE       = 11
 ERROR_PROFILE_NOT_FOUND = 12
 ERROR_BAD_TOKENS        = 13
-ERROR_FIELD_REQUIRED    = 14
\ No newline at end of file
+ERROR_FIELD_REQUIRED    = 14
+
+FPS_DRM_KEYGENERATOR_URI_TEMPLATE = 'https://cpix.ezdrm.com/KeyGenerator/cpix.aspx?k=%s&u=%s&p=%s&c=resourcename&m=2'
+CENC_DRM_KEYGENERATOR_URI_TEMPLATE = 'https://cpix.ezdrm.com/KeyGenerator/cpix.aspx?k=%s&u=%s&p=%s&c=resourcename&m=1'
+DRM_KEY_URL_TEMPLATE = 'skd://fps.ezdrm.com/;%s'
\ No newline at end of file
